@@ -11,10 +11,14 @@
 
 #include "dolphintabwidget.h"
 #include <config-baloo.h>
+#include <KFileItemActions>
 #include <kio/fileundomanager.h>
-#include <KSortableList>
 #include <kxmlguiwindow.h>
 
+#ifdef HAVE_BALOO
+    #include "panels/information/informationpanel.h"
+#endif
+
 #include <QIcon>
 #include <QList>
 #include <QMenu>
@@ -37,7 +41,6 @@ class KNewFileMenu;
 class KHelpMenu;
 class KToolBarPopupAction;
 class QToolButton;
-class QIcon;
 class PlacesPanel;
 class TerminalPanel;
 
@@ -193,6 +196,12 @@ Q_SIGNALS:
      */
     void requestItemInfo(const KFileItem& item);
 
+    /**
+     * It is emitted when in the current view, files are changed,
+     * or dirs have files/removed from them.
+     */
+    void fileItemsChanged(const KFileItemList &changedFileItems);
+
     /**
      * Is emitted if the settings have been changed.
      */
@@ -216,6 +225,9 @@ protected:
     /** Handles QWhatsThisClickedEvent and passes all others on. */
     bool eventFilter(QObject*, QEvent*) override;
 
+    /** Sets a sane initial window size **/
+    QSize sizeHint() const override;
+
 protected Q_SLOTS:
     /**
      * Calls the base method KXmlGuiWindow::saveNewToolbarConfig().
@@ -459,9 +471,15 @@ private Q_SLOTS:
                          const QUrl& url,
                          const QList<QAction*>& customActions);
 
-    void updateControlMenu();
-    void updateToolBar();
-    void slotControlButtonDeleted();
+    /**
+     * Updates the menu that is by default at the right end of the toolbar.
+     *
+     * In true "simple by default" fashion, the menu only contains the most important
+     * and necessary actions to be able to use Dolphin. This is supposed to hold true even
+     * if the user does not know how to open a context menu. More advanced actions can be
+     * discovered through a sub-menu (@see KConfigWidgets::KHamburgerMenu::setMenuBarAdvertised()).
+     */
+    void updateHamburgerMenu();
 
     /**
      * Is called if the user clicked an item in the Places Panel.
@@ -566,16 +584,6 @@ private:
     void updateViewActions();
     void updateGoActions();
 
-    void createControlButton();
-    void deleteControlButton();
-
-    /**
-     * Adds the action \p action to the menu \p menu in
-     * case if it has not added already to the toolbar.
-     * @return True if the action has been added to the menu.
-     */
-    bool addActionToMenu(QAction* action, QMenu* menu);
-
     /**
      * Connects the signals from the created DolphinView with
      * the DolphinViewContainer \a container with the corresponding slots of
@@ -616,6 +624,16 @@ private:
     /** Returns preferred search tool as configured in "More Search Tools" menu. */
     QPointer<QAction> preferredSearchTool();
 
+    /**
+     * Adds this action to the mainWindow's toolbar and saves the change
+     * in the users ui configuration file.
+     * This method is only needed for migration and should be removed once we can expect
+     * that pretty much all users have been migrated. Remove in 2026 because that's when
+     * even the most risk-averse distros will already have been forced to upgrade.
+     * @return true if successful. Otherwise false.
+     */
+    bool addHamburgerMenuToToolbar();
+
 private:
     /**
      * Implements a custom error handling for the undo manager. This
@@ -653,10 +671,8 @@ private:
     KToolBarPopupAction* m_backAction;
     KToolBarPopupAction* m_forwardAction;
 
-    /** Makes sure that only one object is ever connected to the history. */
-    QMetaObject::Connection m_updateHistoryConnection;
-
     QMenu m_searchTools;
+    KFileItemActions m_fileItemActions;
 
 };
 
