@@ -8,11 +8,13 @@
 
 #include <KIO/JobUiDelegate>
 #include <KIO/PreviewJob>
+#include <KConfigGroup>
 #include <KIconEffect>
 #include <KIconLoader>
 #include <KJobWidgets>
 #include <KLocalizedString>
 #include <KSeparator>
+#include <KSharedConfig>
 #include <KStringHandler>
 #include <QPainterPath>
 
@@ -96,6 +98,7 @@ InformationPanelContent::InformationPanelContent(QWidget* parent) :
     m_nameLabel->setTextFormat(Qt::PlainText);
     m_nameLabel->setAlignment(Qt::AlignHCenter);
     m_nameLabel->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed);
+    m_nameLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
 
     const bool previewsShown = InformationPanelSettings::previewsShown();
     m_preview->setVisible(previewsShown);
@@ -184,7 +187,8 @@ void InformationPanelContent::refreshPixmapView()
     // can be shown within a short timeframe.
     m_outdatedPreviewTimer->start();
 
-    QStringList plugins = KIO::PreviewJob::availablePlugins();
+    const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
+    const QStringList plugins = globalConfig.readEntry("Plugins", KIO::PreviewJob::defaultPlugins());
     m_previewJob = new KIO::PreviewJob(KFileItemList() << m_item,
                                        QSize(m_preview->width(), m_preview->height()),
                                        &plugins);
